@@ -1,4 +1,4 @@
-package Dist::Zilla::MVP::Reader::Perl 6.010;
+package Dist::Zilla::MVP::Reader::Perl 6.017;
 # ABSTRACT: the reader for dist.pl files
 
 use Moose;
@@ -30,7 +30,7 @@ sub read_into_assembler {
 
   while (my ($ident, $arg) = splice @$plugins, 0, 2) {
     unless (ref $arg) {
-      unshift @$plugins, $arg;
+      unshift @$plugins, $arg if defined $arg;
       $arg = [];
     }
 
@@ -43,9 +43,9 @@ sub read_into_assembler {
   }
 
   # should be done ... elsewhere? -- rjbs, 2009-08-24
-  $self->assembler->end_section if $self->assembler->current_section;
+  $asm->end_section if $asm->current_section;
 
-  return $self->assembler->sequence;
+  return $asm->sequence;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -63,7 +63,7 @@ Dist::Zilla::MVP::Reader::Perl - the reader for dist.pl files
 
 =head1 VERSION
 
-version 6.010
+version 6.017
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
