@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::PodVersion 6.010;
+package Dist::Zilla::Plugin::PodVersion 6.017;
 # ABSTRACT: add a VERSION head1 to each Perl document
 
 use Moose;
@@ -18,6 +18,11 @@ use namespace::autoclean;
 #pod added after C<=head1 NAME>.  If there is no such section, the version section
 #pod will not be added.
 #pod
+#pod Note that this plugin is not useful if you are using the
+#pod L<[PodWeaver]|Dist::Zilla::Plugin::PodWeaver> plugin, as it also adds a
+#pod C<=head1 VERSION> section (via the L<[Version]|Pod::Weaver::Section::Version>
+#pod section).
+#pod
 #pod =cut
 
 sub munge_files {
@@ -98,7 +103,7 @@ Dist::Zilla::Plugin::PodVersion - add a VERSION head1 to each Perl document
 
 =head1 VERSION
 
-version 6.010
+version 6.017
 
 =head1 DESCRIPTION
 
@@ -107,6 +112,11 @@ distribution, indicating the version of the dist being built.  This section is
 added after C<=head1 NAME>.  If there is no such section, the version section
 will not be added.
 
+Note that this plugin is not useful if you are using the
+L<[PodWeaver]|Dist::Zilla::Plugin::PodWeaver> plugin, as it also adds a
+C<=head1 VERSION> section (via the L<[Version]|Pod::Weaver::Section::Version>
+section).
+
 =head1 SEE ALSO
 
 Core Dist::Zilla plugins:
@@ -120,7 +130,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
